GOA POP historical fishery length comp data
goa_pop_fixed_fish_length_comp.RdA dataset containing length comp collection data by year for 1963-1977
goa_pop_fixed_fish_length_comp.RdA dataset containing length comp collection data by year for 1963-1977