q_bts_gap_agecomp.Rdquery GAP bottom trawl survey agecomps
q_bts_gap_agecomp(year, species, area, db, print_sql = FALSE, save = TRUE)max year to retrieve data from
5 digit species code (e.g., 10110) - can place multiple in a vector c(10110, 10130)
options: ebs, ai, goa, nbs, ebs_slope, ebs_nbs, default: goa
data server to connect to (akfin)
outputs the sql query instead of calling the data (default: false)
saves a file to the data/raw folder, otherwise sends output to global enviro (default: true)
saves bts length data as data/raw/bts_gap_agecomp_data.csv or outputs to the global environment, also saves a copy of the SQL code used for the query and stores it in the data/sql folder.
if (FALSE) { # \dontrun{
db <- afscdata::connect()
q_bts_gap_agecomp(year=2022, species=21921, area = "goa", db = db)
} # }