query nmfs longine survey specimen data (age, length, weight, sex, maturity). only available for sablefish!
q_lls_sable_specimen.Rdlongline database documentation available on akfin
Usage
q_lls_sable_specimen(
year,
area = c("goa", "bs", "ai"),
use_historical = FALSE,
db = akfin,
print_sql = FALSE,
save = TRUE
)Arguments
- year
max year to retrieve data from
- area
options are 'goa', 'bs', 'ai', or a combo. default=c('goa', 'bs', 'ai')
- use_historical
T/F include historical Japanese survey data in the results (default: false)
- db
the database to query (akfin)
- print_sql
outputs the sql query instead of calling the data (default: false) - save must be false
- save
save the file in designated folder, if FALSE outputs to global environment